@@ -1,4 +1,4 @@
-version = "0.0.6"
+version = "0.0.7"
 language = "en-US"
 timeout = 15
 user = None
@@ -29,14 +29,14 @@ from .pixkey.__pixkey import PixKey
 from . import pixclaim
 from .pixclaim.__pixclaim import PixClaim
 
-from . import brcodecertificate
-from .brcodecertificate.__brcodecertificate import BrcodeCertificate
+from . import pixdomain
+from .pixdomain.__pixdomain import PixDomain
 
-from . import infractionreport
-from .infractionreport.__infractionreport import InfractionReport
+from . import pixinfraction
+from .pixinfraction.__pixinfraction import PixInfraction
 
-from . import reversalrequest
-from .reversalrequest.__reversalrequest import ReversalRequest
+from . import pixchargeback
+from .pixchargeback.__pixchargeback import PixChargeback
 
 from . import issuingauthorization
 from .issuingauthorization.__issuingauthorization import IssuingAuthorization
@@ -71,4 +71,7 @@ from .issuingbin.__issuingbin import IssuingBin
 from . import __issuingrule
 from .__issuingrule.__issuingrule import IssuingRule
 
+from . import webhook
+from .webhook.__webhook import Webhook
+
 from .utils import endtoendid, returnid
