@@ -1,3 +1,4 @@
+from starkcore.utils.api import from_api_json
 from starkcore.utils.resource import Resource
 
 
@@ -13,7 +14,7 @@ class IssuingRule(Resource):
     - currency_code [string, default "BRL"]: code of the currency that the rule amount refers to. ex: "BRL" or "USD"
     - categories [list of strings, default []]: merchant categories accepted by the rule. ex: ["eatingPlacesRestaurants", "travelAgenciesTourOperators"]
     - countries [list of strings, default []]: countries accepted by the rule. ex: ["BRA", "USA"]
-    - methods [list of strings, default []]: card purchase methods accepted by the rule. ex: ["contactless", "manual"]
+    - methods [list of strings, default []]: card purchase methods accepted by the rule. ex: ["chip", "token", "server", "manual", "magstripe", "contactless"]
     ## Attributes (expanded return-only):
     - counter_amount [integer]: current rule spent amount. ex: 1000
     - currency_symbol [string]: currency symbol. ex: "R$"
@@ -35,3 +36,19 @@ class IssuingRule(Resource):
         self.categories = categories
         self.countries = countries
         self.methods = methods
+
+
+_resource = {"class": IssuingRule, "name": "IssuingRule"}
+
+
+def parse_rules(rules):
+    parsed_rules = []
+    if rules is None:
+        return rules
+    for rule in rules:
+        if isinstance(rule, IssuingRule):
+            parsed_rules.append(rule)
+            continue
+        parsed_rules.append(from_api_json(_resource, rule))
+    return parsed_rules
+
